##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Record(base.RecordModelBase):
    """Record model for :obj:`chat.bsky.actor.declaration`."""

    allow_incoming: t.Union[t.Literal['all'], t.Literal['none'], t.Literal['following'], str]  #: Allow incoming.

    py_type: t.Literal['chat.bsky.actor.declaration'] = Field(
        default='chat.bsky.actor.declaration', alias='$type', frozen=True
    )


class GetRecordResponse(base.SugarResponseModelBase):
    """Get record response for :obj:`models.ChatBskyActorDeclaration.Record`."""

    uri: str  #: The URI of the record.
    value: 'models.ChatBskyActorDeclaration.Record'  #: The record.
    cid: t.Optional[str] = None  #: The CID of the record.


class ListRecordsResponse(base.SugarResponseModelBase):
    """List records response for :obj:`models.ChatBskyActorDeclaration.Record`."""

    records: t.Dict[str, 'models.ChatBskyActorDeclaration.Record']  #: Map of URIs to records.
    cursor: t.Optional[str] = None  #: Next page cursor.


class CreateRecordResponse(base.SugarResponseModelBase):
    """Create record response for :obj:`models.ChatBskyActorDeclaration.Record`."""

    uri: str  #: The URI of the record.
    cid: str  #: The CID of the record.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`app.bsky.feed.sendInteractions`."""

    interactions: t.List['models.AppBskyFeedDefs.Interaction']  #: Interactions.


class DataDict(t.TypedDict):
    interactions: t.List['models.AppBskyFeedDefs.Interaction']  #: Interactions.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`app.bsky.feed.sendInteractions`."""



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class DisableRule(base.ModelBase):
    """Definition model for :obj:`app.bsky.feed.postgate`. Disables embedding of this post."""

    py_type: t.Literal['app.bsky.feed.postgate#disableRule'] = Field(
        default='app.bsky.feed.postgate#disableRule', alias='$type', frozen=True
    )


class Record(base.RecordModelBase):
    """Record model for :obj:`app.bsky.feed.postgate`."""

    created_at: string_formats.DateTime  #: Created at.
    post: string_formats.AtUri  #: Reference (AT-URI) to the post record.
    detached_embedding_uris: t.Optional[t.List[string_formats.AtUri]] = Field(
        default=None, max_length=50
    )  #: List of AT-URIs embedding this post that the author has detached from.
    embedding_rules: t.Optional[
        t.List[te.Annotated[t.Union['models.AppBskyFeedPostgate.DisableRule'], Field(discriminator='py_type')]]
    ] = Field(
        default=None, max_length=5
    )  #: List of rules defining who can embed this post. If value is an empty array or is undefined, no particular rules apply and anyone can embed.

    py_type: t.Literal['app.bsky.feed.postgate'] = Field(default='app.bsky.feed.postgate', alias='$type', frozen=True)


class GetRecordResponse(base.SugarResponseModelBase):
    """Get record response for :obj:`models.AppBskyFeedPostgate.Record`."""

    uri: str  #: The URI of the record.
    value: 'models.AppBskyFeedPostgate.Record'  #: The record.
    cid: t.Optional[str] = None  #: The CID of the record.


class ListRecordsResponse(base.SugarResponseModelBase):
    """List records response for :obj:`models.AppBskyFeedPostgate.Record`."""

    records: t.Dict[str, 'models.AppBskyFeedPostgate.Record']  #: Map of URIs to records.
    cursor: t.Optional[str] = None  #: Next page cursor.


class CreateRecordResponse(base.SugarResponseModelBase):
    """Create record response for :obj:`models.AppBskyFeedPostgate.Record`."""

    uri: str  #: The URI of the record.
    cid: str  #: The CID of the record.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`com.atproto.sync.listRepos`."""

    cursor: t.Optional[str] = None  #: Cursor.
    limit: t.Optional[int] = Field(default=500, ge=1, le=1000)  #: Limit.


class ParamsDict(t.TypedDict):
    cursor: te.NotRequired[t.Optional[str]]  #: Cursor.
    limit: te.NotRequired[t.Optional[int]]  #: Limit.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`com.atproto.sync.listRepos`."""

    repos: t.List['models.ComAtprotoSyncListRepos.Repo']  #: Repos.
    cursor: t.Optional[str] = None  #: Cursor.


class Repo(base.ModelBase):
    """Definition model for :obj:`com.atproto.sync.listRepos`."""

    did: string_formats.Did  #: Did.
    head: string_formats.Cid  #: Current repo commit CID.
    rev: string_formats.Tid  #: Rev.
    active: t.Optional[bool] = None  #: Active.
    status: t.Optional[
        t.Union[
            t.Literal['takendown'],
            t.Literal['suspended'],
            t.Literal['deleted'],
            t.Literal['deactivated'],
            t.Literal['desynchronized'],
            t.Literal['throttled'],
            str,
        ]
    ] = None  #: If active=false, this optional field indicates a possible reason for why the account is not active. If active=false and no status is supplied, then the host makes no claim for why the repository is no longer being hosted.

    py_type: t.Literal['com.atproto.sync.listRepos#repo'] = Field(
        default='com.atproto.sync.listRepos#repo', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`tools.ozone.signature.findRelatedAccounts`."""

    did: string_formats.Did  #: Did.
    cursor: t.Optional[str] = None  #: Cursor.
    limit: t.Optional[int] = Field(default=50, ge=1, le=100)  #: Limit.


class ParamsDict(t.TypedDict):
    did: string_formats.Did  #: Did.
    cursor: te.NotRequired[t.Optional[str]]  #: Cursor.
    limit: te.NotRequired[t.Optional[int]]  #: Limit.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`tools.ozone.signature.findRelatedAccounts`."""

    accounts: t.List['models.ToolsOzoneSignatureFindRelatedAccounts.RelatedAccount']  #: Accounts.
    cursor: t.Optional[str] = None  #: Cursor.


class RelatedAccount(base.ModelBase):
    """Definition model for :obj:`tools.ozone.signature.findRelatedAccounts`."""

    account: 'models.ComAtprotoAdminDefs.AccountView'  #: Account.
    similarities: t.Optional[t.List['models.ToolsOzoneSignatureDefs.SigDetail']] = None  #: Similarities.

    py_type: t.Literal['tools.ozone.signature.findRelatedAccounts#relatedAccount'] = Field(
        default='tools.ozone.signature.findRelatedAccounts#relatedAccount', alias='$type', frozen=True
    )
